# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['autarco']

package_data = \
{'': ['*']}

install_requires = \
['aiohttp>=3.0.0', 'yarl>=1.6.0']

setup_kwargs = {
    'name': 'autarco',
    'version': '0.1.0',
    'description': 'Asynchronous Python client for the Autarco Inverters',
    'long_description': '## Python - Autarco Client\n\n<!-- PROJECT SHIELDS -->\n[![GitHub Release][releases-shield]][releases]\n[![Python Versions][python-versions-shield]][pypi]\n![Project Stage][project-stage-shield]\n![Project Maintenance][maintenance-shield]\n[![License][license-shield]](LICENSE)\n\n[![GitHub Activity][commits-shield]][commits-url]\n[![Forks][forks-shield]][forks-url]\n[![Stargazers][stars-shield]][stars-url]\n[![Issues][issues-shield]][issues-url]\n[![GitHub Last Commit][last-commit-shield]][commits-url]\n\n[![Code Quality][code-quality-shield]][code-quality]\n[![Maintainability][maintainability-shield]][maintainability-url]\n[![Code Coverage][codecov-shield]][codecov-url]\n[![Build Status][build-shield]][build-url]\n\nAsynchronous Python client for the Autarco Inverters.\n\n## About\n\nA python package with which you can read the data of your [Autarco][autarco]\nInverter(s). This is done by making a request to the [My Autarco][my-autarco]\nplatform, for this you will need the `public_key`, `username` and `password`.\nThe data on the platform is updated every 5 minutes.\n\n### Public key\n\nYou can find this in the url after logging in,\nexample: `https://my.autarco.com/site/{public_key}`\n\n## Installation\n\n```bash\npip install autarco\n```\n\n## Usage\n\n```python\nimport asyncio\n\nfrom autarco import Autarco\n\n\nasync def main():\n    """Show example on getting Autarco data."""\n    async with Autarco(\n        public_key="key",\n        username="autarco@test.com",\n        password="password",\n    ) as client:\n        inverters = await client.all_inverter()\n        solar = await client.solar()\n        account = await client.account()\n        print(inverters)\n        print(solar)\n        print(account)\n\n\nif __name__ == "__main__":\n    loop = asyncio.get_event_loop()\n    loop.run_until_complete(main())\n```\n\n## Data\n\nYou can read the following data with this package:\n\n### Inverter(s)\n\n- Serial Number\n- Current Power Production (W)\n- Total Energy Production (kWh)\n- Health Status\n\n### Solar\n\n- Current Power Production (W)\n- Energy Production - Today (kWh)\n- Energy Production - Month (kWh)\n- Energy Production - Total (kWh)\n\n### Account\n\n- Public Key (str)\n- Name (str)\n- City (str)\n- State (str)\n- Country (str)\n- Timezone (str)\n\n## Setting up development environment\n\nThis Python project is fully managed using the [Poetry][poetry] dependency\nmanager.\n\nYou need at least:\n\n- Python 3.9+\n- [Poetry][poetry-install]\n\nInstall all packages, including all development requirements:\n\n```bash\npoetry install\n```\n\nPoetry creates by default an virtual environment where it installs all\nnecessary pip packages, to enter or exit the venv run the following commands:\n\n```bash\npoetry shell\nexit\n```\n\nSetup the pre-commit check, you must run this inside the virtual environment:\n\n```bash\npre-commit install\n```\n\n*Now you\'re all set to get started!*\n\nAs this repository uses the [pre-commit][pre-commit] framework, all changes\nare linted and tested with each commit. You can run all checks and tests\nmanually, using the following command:\n\n```bash\npoetry run pre-commit run --all-files\n```\n\nTo run just the Python tests:\n\n```bash\npoetry run pytest\n```\n\n## License\n\nMIT License\n\nCopyright (c) 2022 Klaas Schoute\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the "Software"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.\n\n<!-- PROJECT -->\n[autarco]: https://www.autarco.com\n[my-autarco]: https://my.autarco.com\n\n<!-- MARKDOWN LINKS & IMAGES -->\n[build-shield]: https://github.com/klaasnicolaas/python-autarco/actions/workflows/tests.yaml/badge.svg\n[build-url]: https://github.com/klaasnicolaas/python-autarco/actions/workflows/tests.yaml\n[code-quality-shield]: https://img.shields.io/lgtm/grade/python/g/klaasnicolaas/python-autarco.svg?logo=lgtm&logoWidth=18\n[code-quality]: https://lgtm.com/projects/g/klaasnicolaas/python-autarco/context:python\n[commits-shield]: https://img.shields.io/github/commit-activity/y/klaasnicolaas/python-autarco.svg\n[commits-url]: https://github.com/klaasnicolaas/python-autarco/commits/master\n[codecov-shield]: https://codecov.io/gh/klaasnicolaas/python-autarco/branch/master/graph/badge.svg?token=VQTR24YFQ9\n[codecov-url]: https://codecov.io/gh/klaasnicolaas/python-autarco\n[forks-shield]: https://img.shields.io/github/forks/klaasnicolaas/python-autarco.svg\n[forks-url]: https://github.com/klaasnicolaas/python-autarco/network/members\n[issues-shield]: https://img.shields.io/github/issues/klaasnicolaas/python-autarco.svg\n[issues-url]: https://github.com/klaasnicolaas/python-autarco/issues\n[license-shield]: https://img.shields.io/github/license/klaasnicolaas/python-autarco.svg\n[last-commit-shield]: https://img.shields.io/github/last-commit/klaasnicolaas/python-autarco.svg\n[maintenance-shield]: https://img.shields.io/maintenance/yes/2022.svg\n[maintainability-shield]: https://api.codeclimate.com/v1/badges/443c476612a574d82467/maintainability\n[maintainability-url]: https://codeclimate.com/github/klaasnicolaas/python-autarco/maintainability\n[project-stage-shield]: https://img.shields.io/badge/project%20stage-experimental-yellow.svg\n[pypi]: https://pypi.org/project/autarco/\n[python-versions-shield]: https://img.shields.io/pypi/pyversions/autarco\n[releases-shield]: https://img.shields.io/github/release/klaasnicolaas/python-autarco.svg\n[releases]: https://github.com/klaasnicolaas/python-autarco/releases\n[stars-shield]: https://img.shields.io/github/stars/klaasnicolaas/python-autarco.svg\n[stars-url]: https://github.com/klaasnicolaas/python-autarco/stargazers\n\n<!-- Development -->\n[poetry-install]: https://python-poetry.org/docs/#installation\n[poetry]: https://python-poetry.org\n[pre-commit]: https://pre-commit.com\n',
    'author': 'Klaas Schoute',
    'author_email': 'hello@student-techlife.com',
    'maintainer': 'Klaas Schoute',
    'maintainer_email': 'hello@student-techlife.com',
    'url': 'https://github.com/klaasnicolaas/python-autarco',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
